# -*- coding: utf-8 -*-

import os
import argparse
import logging
logging.basicConfig(level=logging.DEBUG)
from common import find_mxnet, data, fit
from common.util import download_file
import mxnet as mx

# 一个cifar10图片分类的例子
if __name__ == '__main__':
    # 训练和验证集的ImageRecord文件，可以直接读取OSS上的文件

    # 解析参数
    parser = argparse.ArgumentParser(description="train cifar10",
                                     formatter_class=argparse.ArgumentDefaultsHelpFormatter)

    # 解析输入数据路径，包括训练集和测试集，这两个路径是必填项
    # 在这个例子中，我们在hyperparam.txt中填写的分别是
    # 'oss://imagenet/mxnet-ext-data/cifar10_train.rec'和'oss://imagenet/mxnet-ext-data/cifar10_val.rec'
    parser.add_argument('--data-train', type=str, help='the training data')
    parser.add_argument('--data-val', type=str, help='the validation data')

    # 解析模型输出路径参数，可选。不为空即会输出模型到这个目录，直接支持一个OSS的路径。
    # 在这个例子中，我们在界面上Checkpoint目录这项填写的是'oss://imagenet/mxnet-ext-model/'
    parser.add_argument('--checkpointDir', type=str, dest='model_prefix',
                       help='model prefix')

    fit.add_fit_args(parser)
    data.add_data_args(parser)
    data.add_data_aug_args(parser)
    data.set_data_aug_level(parser, 2)

    # 配置一些默认参数
    parser.set_defaults(
        # 网络模型类型，这里使用resnet
        network        = 'resnet',
        # resnet的层数，这里配置为50层
        num_layers     = 50,

        # 总类别数
        num_classes    = 10,
        
        # 总样本数，cifar10是5万
        num_examples  = 50000,

        # 图片的形状
        image_shape    = '3,28,28',

        # 图片augmentation的padding大小，含义请参考http://mxnet.io/api/python/io.html#mxnet.io.ImageRecordIter
        pad_size       = 4,

        # 训练的minibatch大小
        batch_size     = 128,

        # 训练的epoch
        num_epochs     = 1,

        # learning rate配置
        lr             = .1,
        lr_step_epochs = '200,250',
    )
    args = parser.parse_args()

    # load network
    from importlib import import_module
    net = import_module('symbol.'+args.network)

    # 创建resnet symbol对象
    sym = net.get_symbol(**vars(args))

    # 开始训练
    fit.fit(args, sym, data.get_rec_iter)
